@@ -11,6 +11,8 @@ from tests import (
     DataClassItem,
     DataClassItemNested,
     DataClassWithoutInit,
+    PydanticModel,
+    PydanticModelNested,
     ScrapySubclassedItem,
     ScrapySubclassedItemNested,
 )
@@ -68,6 +70,15 @@ class ItemAdapterReprTestCase(unittest.TestCase):
             repr(adapter), "<ItemAdapter for AttrsItemWithoutInit(name='set after init')>"
         )
 
+    @unittest.skipIf(not PydanticModel, "pydantic module is not available")
+    def test_repr_pydantic(self):
+        item = PydanticModel(name="asdf", value=1234)
+        adapter = ItemAdapter(item)
+        self.assertEqual(
+            repr(adapter),
+            "<ItemAdapter for PydanticModel(name='asdf', value=1234)>",
+        )
+
 
 class ItemAdapterInitError(unittest.TestCase):
     def test_non_item(self):
@@ -196,7 +207,7 @@ class DictTestCase(unittest.TestCase, BaseTestMixin):
     item_class_nested = dict
 
     def test_get_value_keyerror_item_dict(self):
-        """Instantiate without default values"""
+        """Instantiate without default values."""
         adapter = ItemAdapter(self.item_class())
         with self.assertRaises(KeyError):
             adapter["name"]
@@ -220,12 +231,18 @@ class ScrapySubclassedItemTestCase(NonDictTestMixin, unittest.TestCase):
     item_class_nested = ScrapySubclassedItemNested
 
     def test_get_value_keyerror_item_dict(self):
-        """Instantiate without default values"""
+        """Instantiate without default values."""
         adapter = ItemAdapter(self.item_class())
         with self.assertRaises(KeyError):
             adapter["name"]
 
 
+class PydanticModelTestCase(NonDictTestMixin, unittest.TestCase):
+
+    item_class = PydanticModel
+    item_class_nested = PydanticModelNested
+
+
 class DataClassItemTestCase(NonDictTestMixin, unittest.TestCase):
 
     item_class = DataClassItem
