@@ -1,3 +1,4 @@
+import importlib
 import unittest
 from unittest import mock
 from types import MappingProxyType
@@ -7,13 +8,25 @@ from itemadapter.utils import (
     is_attrs_instance,
     is_dataclass_instance,
     is_item,
+    is_pydantic_instance,
     is_scrapy_item,
 )
+from itemadapter import ItemAdapter
 
-from tests import AttrsItem, DataClassItem, ScrapyItem, ScrapySubclassedItem
+from tests import (
+    AttrsItem,
+    DataClassItem,
+    PydanticModel,
+    PydanticSpecialCasesModel,
+    ScrapyItem,
+    ScrapySubclassedItem,
+)
 
 
 def mocked_import(name, *args, **kwargs):
+    """Allow only internal itemadapter imports."""
+    if name.split(".")[0] == "itemadapter":
+        return importlib.__import__(name, *args, **kwargs)
     raise ImportError(name)
 
 
@@ -48,22 +61,36 @@ class ItemLikeTestCase(unittest.TestCase):
         self.assertFalse(is_item(DataClassItem))
         self.assertFalse(is_item(ScrapySubclassedItem))
         self.assertFalse(is_item(AttrsItem))
+        self.assertFalse(is_item(PydanticModel))
+        self.assertFalse(ItemAdapter.is_item_class(list))
+        self.assertFalse(ItemAdapter.is_item_class(int))
+        self.assertFalse(ItemAdapter.is_item_class(tuple))
 
     def test_true_dict(self):
         self.assertTrue(is_item({"a": "dict"}))
+        self.assertTrue(ItemAdapter.is_item_class(dict))
 
     @unittest.skipIf(not ScrapySubclassedItem, "scrapy module is not available")
     def test_true_scrapy(self):
         self.assertTrue(is_item(ScrapyItem()))
         self.assertTrue(is_item(ScrapySubclassedItem(name="asdf", value=1234)))
+        self.assertTrue(ItemAdapter.is_item_class(ScrapyItem))
+        self.assertTrue(ItemAdapter.is_item_class(ScrapySubclassedItem))
 
     @unittest.skipIf(not DataClassItem, "dataclasses module is not available")
     def test_true_dataclass(self):
         self.assertTrue(is_item(DataClassItem(name="asdf", value=1234)))
+        self.assertTrue(ItemAdapter.is_item_class(DataClassItem))
 
     @unittest.skipIf(not AttrsItem, "attrs module is not available")
     def test_true_attrs(self):
         self.assertTrue(is_item(AttrsItem(name="asdf", value=1234)))
+        self.assertTrue(ItemAdapter.is_item_class(AttrsItem))
+
+    @unittest.skipIf(not PydanticModel, "pydantic module is not available")
+    def test_true_pydantic(self):
+        self.assertTrue(is_item(PydanticModel(name="asdf", value=1234)))
+        self.assertTrue(ItemAdapter.is_item_class(PydanticModel))
 
 
 class AttrsTestCase(unittest.TestCase):
@@ -73,6 +100,8 @@ class AttrsTestCase(unittest.TestCase):
         self.assertFalse(is_attrs_instance(1234))
         self.assertFalse(is_attrs_instance(object()))
         self.assertFalse(is_attrs_instance(ScrapyItem()))
+        self.assertFalse(is_attrs_instance(DataClassItem()))
+        self.assertFalse(is_attrs_instance(PydanticModel()))
         self.assertFalse(is_attrs_instance(ScrapySubclassedItem()))
         self.assertFalse(is_attrs_instance("a string"))
         self.assertFalse(is_attrs_instance(b"some bytes"))
@@ -112,6 +141,7 @@ class DataclassTestCase(unittest.TestCase):
         self.assertFalse(is_dataclass_instance(object()))
         self.assertFalse(is_dataclass_instance(ScrapyItem()))
         self.assertFalse(is_dataclass_instance(AttrsItem()))
+        self.assertFalse(is_dataclass_instance(PydanticModel()))
         self.assertFalse(is_dataclass_instance(ScrapySubclassedItem()))
         self.assertFalse(is_dataclass_instance("a string"))
         self.assertFalse(is_dataclass_instance(b"some bytes"))
@@ -144,6 +174,52 @@ class DataclassTestCase(unittest.TestCase):
             get_field_meta_from_class(DataClassItem, "non_existent")
 
 
+class PydanticTestCase(unittest.TestCase):
+    def test_false(self):
+        self.assertFalse(is_pydantic_instance(int))
+        self.assertFalse(is_pydantic_instance(sum))
+        self.assertFalse(is_pydantic_instance(1234))
+        self.assertFalse(is_pydantic_instance(object()))
+        self.assertFalse(is_pydantic_instance(ScrapyItem()))
+        self.assertFalse(is_pydantic_instance(AttrsItem()))
+        self.assertFalse(is_pydantic_instance(DataClassItem()))
+        self.assertFalse(is_pydantic_instance(ScrapySubclassedItem()))
+        self.assertFalse(is_pydantic_instance("a string"))
+        self.assertFalse(is_pydantic_instance(b"some bytes"))
+        self.assertFalse(is_pydantic_instance({"a": "dict"}))
+        self.assertFalse(is_pydantic_instance(["a", "list"]))
+        self.assertFalse(is_pydantic_instance(("a", "tuple")))
+        self.assertFalse(is_pydantic_instance({"a", "set"}))
+        self.assertFalse(is_pydantic_instance(PydanticModel))
+
+    @unittest.skipIf(not PydanticModel, "pydantic module is not available")
+    @mock.patch("builtins.__import__", mocked_import)
+    def test_module_not_available(self):
+        self.assertFalse(is_pydantic_instance(PydanticModel(name="asdf", value=1234)))
+        with self.assertRaises(TypeError, msg="PydanticModel is not a valid item class"):
+            get_field_meta_from_class(PydanticModel, "name")
+
+    @unittest.skipIf(not PydanticModel, "pydantic module is not available")
+    def test_true(self):
+        self.assertTrue(is_pydantic_instance(PydanticModel()))
+        self.assertTrue(is_pydantic_instance(PydanticModel(name="asdf", value=1234)))
+        # field metadata
+        self.assertEqual(
+            get_field_meta_from_class(PydanticModel, "name"),
+            MappingProxyType({"serializer": str}),
+        )
+        self.assertEqual(
+            get_field_meta_from_class(PydanticModel, "value"),
+            MappingProxyType({"serializer": int}),
+        )
+        self.assertEqual(
+            get_field_meta_from_class(PydanticSpecialCasesModel, "special_cases"),
+            MappingProxyType({"alias": "special_cases", "allow_mutation": False}),
+        )
+        with self.assertRaises(KeyError, msg="PydanticModel does not support field: non_existent"):
+            get_field_meta_from_class(PydanticModel, "non_existent")
+
+
 class ScrapyItemTestCase(unittest.TestCase):
     def test_false(self):
         self.assertFalse(is_scrapy_item(int))
@@ -151,6 +227,8 @@ class ScrapyItemTestCase(unittest.TestCase):
         self.assertFalse(is_scrapy_item(1234))
         self.assertFalse(is_scrapy_item(object()))
         self.assertFalse(is_scrapy_item(AttrsItem()))
+        self.assertFalse(is_scrapy_item(DataClassItem()))
+        self.assertFalse(is_scrapy_item(PydanticModel()))
         self.assertFalse(is_scrapy_item("a string"))
         self.assertFalse(is_scrapy_item(b"some bytes"))
         self.assertFalse(is_scrapy_item({"a": "dict"}))
@@ -189,9 +267,7 @@ except ImportError:
 
 
 class ScrapyDeprecatedBaseItemTestCase(unittest.TestCase):
-    """
-    Tests for deprecated classes. These will go away once the upstream classes are removed.
-    """
+    """Tests for deprecated classes. These will go away once the upstream classes are removed."""
 
     @unittest.skipIf(
         scrapy is None or not hasattr(scrapy.item, "_BaseItem"),
@@ -217,9 +293,7 @@ class ScrapyDeprecatedBaseItemTestCase(unittest.TestCase):
 
     @unittest.skipIf(scrapy is None, "scrapy module is not available")
     def test_removed_baseitem(self):
-        """
-        Mock the scrapy.item module so it does not contain the deprecated _BaseItem class
-        """
+        """Mock the scrapy.item module so it does not contain the deprecated _BaseItem class."""
 
         class MockItemModule:
             Item = ScrapyItem
